PsPathFillRule enum

Fill rule inferred from Photoshop's subpath flags.

Inheritance
Available extensions

Values

evenOdd → const PsPathFillRule

Alternates between filled and unfilled areas at every crossed edge.

nonZero → const PsPathFillRule

Uses the signed winding count of crossed edges.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromFlags(int flags) → PsPathFillRule
Resolves the convention used by known Photoshop vector-mask records.

Constants

values → const List<PsPathFillRule>
A constant List of the values in this enum, in order of their declaration.