PsdImageResourceIds class abstract final

Standard Photoshop image-resource identifiers.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isPath(int id) → bool
Whether id contains a saved vector path.
isPlugin(int id) → bool
Whether id is reserved for a plug-in-defined resource.

Constants

alphaIdentifiers → const int
Alpha-channel identifiers.
alphaNamesPascal → const int
Pascal-string alpha-channel names.
alphaNamesUnicode → const int
Unicode alpha-channel names.
autoSaveFormat → const int
Auto-save format stored as Unicode.
autoSavePath → const int
Auto-save path stored as Unicode.
backgroundColor → const int
Document background color.
captionDigest → const int
Sixteen-byte IPTC caption digest.
clippingPathName → const int
Clipping-path name and options.
colorHalftoning → const int
Color halftone screens.
colorTransferFunctions → const int
Color transfer functions.
copyrightFlag → const int
Copyright flag.
displayInfo → const int
Alpha-channel display information.
documentIdSeed → const int
Seed for document-scoped layer identifiers.
duotoneHalftoning → const int
Duotone halftone screens.
duotoneTransferFunctions → const int
Duotone transfer functions.
effectsVisible → const int
Global layer-effects visibility.
exif1 → const int
Primary EXIF block.
exif3 → const int
Secondary EXIF block.
globalAltitude → const int
Global lighting altitude.
globalAngle → const int
Global lighting angle.
grayscaleHalftoning → const int
Grayscale halftone screens.
grayscaleTransferFunctions → const int
Grayscale transfer functions.
gridAndGuides → const int
Grid and guide settings.
iccProfile → const int
ICC profile bytes.
iccUntagged → const int
Intentionally untagged ICC flag.
indexedColorCount → const int
Number of defined indexed colors.
iptc → const int
IPTC-NAA metadata.
layerComps → const int
Layer-comps descriptor.
layerGroupEnabled → const int
Per-layer group enabled flags.
layerGroups → const int
Layer-group identifiers.
layerSelectionIds → const int
Selected layer identifiers.
layerState → const int
Selected layer index.
originPathInfo → const int
Origin-path descriptor.
pathSelectionState → const int
Current path-selection descriptor.
pixelAspectRatio → const int
Pixel aspect ratio.
printFlags → const int
Page-setup print flags.
printFlagsInfo → const int
Extended print flags.
printInfo → const int
Photoshop CS5 print-information descriptor.
printScale → const int
Print scale and placement.
printStyle → const int
Photoshop CS5 print-style descriptor.
resolutionInfo → const int
Resolution information.
slices → const int
Slice definitions.
thumbnail → const int
Photoshop 5 and later thumbnail.
thumbnailPhotoshop4 → const int
Photoshop 4 thumbnail.
transparencyIndex → const int
Indexed transparency entry.
url → const int
URL stored as a one-byte string.
urlList → const int
URL list.
versionInfo → const int
Photoshop writer and reader version information.
watermark → const int
Watermark flag.
workflowUrl → const int
Workflow URL stored as Unicode.
workingPath → const int
Unsaved working path.
xmp → const int
UTF-8 XMP packet.