PsdMemoryPlanarSource class final

Adapts an in-memory plane to the progressive writer.

Implemented types

Constructors

PsdMemoryPlanarSource({required Uint8List bytes, required int rowBytes})
Creates a source over bytes without copying them.

Properties

bytes → Uint8List
Complete row-major plane supplied by the caller.
final
hashCode → int
The hash code for this object.
no setterinherited
rowBytes → int
Stored bytes in one row.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRows({required int startRow, required int rowCount}) → Future<Uint8List>
Reads rowCount complete rows beginning at startRow.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited