PsdPlacedTransform class final

Eight transform coordinates ordered by the four placed-image corners.

Constructors

PsdPlacedTransform({required double topLeftX, required double topLeftY, required double topRightX, required double topRightY, required double bottomRightX, required double bottomRightY, required double bottomLeftX, required double bottomLeftY})
Creates four-corner placed-image coordinates.
const
PsdPlacedTransform.fromList({required List<double> values})
Creates transform coordinates from the eight stored values.
factory

Properties

bottomLeftX → double
Bottom-left horizontal coordinate.
final
bottomLeftY → double
Bottom-left vertical coordinate.
final
bottomRightX → double
Bottom-right horizontal coordinate.
final
bottomRightY → double
Bottom-right vertical coordinate.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeftX → double
Top-left horizontal coordinate.
final
topLeftY → double
Top-left vertical coordinate.
final
topRightX → double
Top-right horizontal coordinate.
final
topRightY → double
Top-right vertical coordinate.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toList() → List<double>
Returns the eight coordinates in Photoshop storage order.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited