PsdRectangle class final

A rectangle in document pixel coordinates.

Constructors

PsdRectangle({required int top, required int left, required int bottom, required int right})
Creates a rectangle from its four PSD edges.
const
PsdRectangle.fromSize({required int width, required int height})
Creates a rectangle whose origin is zero.
const

Properties

bottom → int
Bottom edge.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
Non-negative pixel height.
no setter
left → int
Left edge.
final
Right edge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → int
Top edge.
final
width → int
Non-negative pixel width.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited