PsdTextBounds class final

Four single-precision bounds stored at the end of a TySh block.

Constructors

PsdTextBounds({required double left, required double top, required double right, required double bottom})
Creates type-tool bounds.
const

Properties

bottom → double
Bottom edge.
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
Left edge.
final
Right edge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
Top edge.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const PsdTextBounds
Empty bounds used by point text without a text box.