PsdTextBox class final

Rectangle used by text-engine box geometry.

Constructors

PsdTextBox({required double left, required double top, required double right, required double bottom})
Creates a text-engine box.
const

Properties

bottom → double
Bottom edge.
final
hashCode → int
The hash code for this object.
no setterinherited
left → double
Left edge.
final
Right edge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double
Top edge.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const PsdTextBox
Empty box.