PsDescriptorItem class final
One keyed value inside a Photoshop action descriptor.
Constructors
- PsDescriptorItem({required String key, required PsDescriptorValue value, bool compactKey = true})
-
Creates a keyed descriptor item.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Photoshop key identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → PsDescriptorValue
-
Typed value associated with key.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited