PsdAlphaChannelDisplay class final
Display color and opacity for one alpha channel.
Constructors
Properties
- colorSpace → int
-
Photoshop color-space code.
final
-
components
→ List<
int> -
Four raw 16-bit color components.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → int
-
Alpha-channel mode code.
final
- opacity → int
-
Opacity from zero through 100.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited