PsdGuide class final
One horizontal or vertical document guide.
Constructors
Properties
- direction → int
-
Raw direction code.
final
- directionType → PsdGuideDirection?
-
Recognized guide direction, or
nullfor an unknown code.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- location → int
-
Guide location in Photoshop's 1/32-pixel coordinate units.
final
- pixels → double
-
Guide location in pixels.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited