PsdHueSaturationAdjustment class final
Modern hue/saturation settings stored in a hue2 block.
- Inheritance
-
- Object
- PsdAdjustment
- PsdHueSaturationAdjustment
Constructors
-
PsdHueSaturationAdjustment({int version = 2, bool colorize = false, PsdHueSaturationValues colorization = const PsdHueSaturationValues(), PsdHueSaturationValues master = const PsdHueSaturationValues(), required List<
PsdHueSaturationRange> ranges, Uint8List? trailingData}) - Creates modern hue/saturation settings.
Properties
- blockKey → String
-
Four-character additional-layer-information key.
no setteroverride
- colorization → PsdHueSaturationValues
-
Colorization values.
final
- colorize → bool
-
Whether Photoshop uses the colorization controls.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- master → PsdHueSaturationValues
-
Master HSL changes.
final
-
ranges
→ List<
PsdHueSaturationRange> -
Six red-through-magenta color ranges.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trailingData → Uint8List
-
Uninterpreted bytes following the documented fields.
final
- type → PsdAdjustmentType
-
Semantic adjustment family.
no setteroverride
- version → int
-
Format version, normally 2.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited