PsdLevelsAdjustment class final
The fixed and extended channel records stored in a levl block.
- Inheritance
-
- Object
- PsdAdjustment
- PsdLevelsAdjustment
Constructors
-
PsdLevelsAdjustment({int version = 2, required List<
PsdLevelRecord> records, List<PsdLevelRecord> extendedRecords = const <PsdLevelRecord>[], int extendedVersion = 3, Uint8List? trailingData}) - Creates levels settings.
- PsdLevelsAdjustment.identity()
-
Creates the 29 neutral levels records expected by Photoshop.
factory
Properties
- blockKey → String
-
Four-character additional-layer-information key.
no setteroverride
-
extendedRecords
→ List<
PsdLevelRecord> -
Optional Photoshop extended channel records.
final
- extendedVersion → int
-
Extended-record format version, normally 3.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
records
→ List<
PsdLevelRecord> -
The 29 standard channel records.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trailingData → Uint8List
-
Uninterpreted bytes following the decoded records.
final
- type → PsdAdjustmentType
-
Semantic adjustment family.
no setteroverride
- version → int
-
Main format version, normally 2.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited