PsdReadOptions class final
Limits untrusted input before allocating decoded image buffers.
Constructors
- PsdReadOptions({int maxPixels = 500000000, int maxLayers = 100000, int maxDecodedBytes = 2147483648})
-
Creates defensive parser limits.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDecodedBytes → int
-
Maximum size of any single decoded channel or merged image.
final
- maxLayers → int
-
Maximum number of layer records.
final
- maxPixels → int
-
Maximum canvas area.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited