PsdTextBounds class final
Four single-precision bounds stored at the end of a TySh block.
Constructors
- PsdTextBounds({required double left, required double top, required double right, required double bottom})
-
Creates type-tool bounds.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- zero → const PsdTextBounds
- Empty bounds used by point text without a text box.