PsdTextDescriptorBounds class final
Bounds stored inside the type-tool action descriptor.
Constructors
- PsdTextDescriptorBounds({required PsdTextUnitValue left, required PsdTextUnitValue top, required PsdTextUnitValue right, required PsdTextUnitValue bottom})
-
Creates descriptor bounds with independent units for every edge.
const
- PsdTextDescriptorBounds.pixels({required double left, required double top, required double right, required double bottom})
-
Creates pixel-based descriptor bounds.
factory
Properties
- bottom → PsdTextUnitValue
-
Bottom edge and its unit.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → PsdTextUnitValue
-
Left edge and its unit.
final
- right → PsdTextUnitValue
-
Right edge and its unit.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → PsdTextUnitValue
-
Top edge and its unit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited