PsdTextWarp class final
Common editable properties of a Photoshop text-warp descriptor.
Constructors
- PsdTextWarp({required PsdTextWarpStyle style, required double value, required double perspective, required double perspectiveOther, required PsdTextOrientation rotation})
-
Creates text-warp settings.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- perspective → double
-
Horizontal perspective amount.
final
- perspectiveOther → double
-
Vertical perspective amount.
final
- rotation → PsdTextOrientation
-
Direction in which the warp is applied.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → PsdTextWarpStyle
-
Selected Photoshop warp preset.
final
- value → double
-
Warp bend amount.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const PsdTextWarp
- Default no-warp settings.